@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from XgridFoundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestXGController (TestCase):
     def testConstants(self):
         self.assertIsInstance(XGControllerWillDeallocNotification, unicode)
